@@ -2,9 +2,11 @@ import subprocess
 import os
 import shlex
 
+from clickable.config.constants import Constants
 from clickable.utils import (
     run_subprocess_call,
     run_subprocess_check_output,
+    run_subprocess_check_call
 )
 from clickable.logger import logger
 from clickable.exceptions import ClickableException
@@ -67,13 +69,13 @@ class ShellCommand(Command):
 
         # Purge the device host key so that SSH doesn't print a scary warning about it
         # (it changes every time the device is reflashed and this is expected)
-        known_hosts = os.path.expanduser('~/.ssh/known_hosts')
+        known_hosts = os.path.join(Constants.host_home, '.ssh/known_hosts')
         subprocess.check_call(shlex.split(f'touch {known_hosts}'))
         subprocess.check_call(
             shlex.split(f'ssh-keygen -f {known_hosts} -R [localhost]:{port}')
         )
 
-        ssh_dir = os.path.expanduser('~/.ssh/')
+        ssh_dir = os.path.join(Constants.host_home, '.ssh/')
         id_pub_candidates = ["id_rsa.pub", "id_ed25519.pub"]
         id_pub = None
 
@@ -114,7 +116,12 @@ class ShellCommand(Command):
         http://bazaar.launchpad.net/~phablet-team/phablet-tools/trunk/view/head:/phablet-shell
         '''
         if self.config.ssh:
-            subprocess.check_call(shlex.split(f'ssh phablet@{self.config.ssh}'))
+            command = ['ssh', f'phablet@{self.config.ssh}']
+
+            if self.config.ssh_port:
+                command += ['-o', f'Port={self.config.ssh_port}']
+
+            run_subprocess_check_call(command)
         else:
             port = self.setup_ssh_via_adb()
 
