@@ -10,6 +10,7 @@ class Constants():
     CUSTOM = 'custom'
     CORDOVA = 'cordova'
     PURE = 'pure'
+    QBS = 'qbs'
     GO = 'go'
     RUST = 'rust'
     PRECOMPILED = 'precompiled'
@@ -28,6 +29,7 @@ class Constants():
         CUSTOM,
         CORDOVA,
         PURE,
+        QBS,
         GO,
         RUST,
         PRECOMPILED
@@ -132,7 +134,8 @@ class Constants():
     }
     host_arch = host_arch_mapping.get(platform.machine().lower(), None)
 
-    clickable_dir = os.path.expanduser('~/.clickable')
+    host_home = os.path.expanduser('~')
+    clickable_dir = os.path.join(host_home, '.clickable')
     clickable_config_path = os.path.join(clickable_dir, 'config.yaml')
     desktop_device_home = os.path.join(clickable_dir, 'home')
     device_home = '/home/phablet'
