@@ -18,13 +18,16 @@ from clickable.utils import (
 from clickable.logger import logger
 from clickable.config.constants import Constants
 from clickable.exceptions import ClickableException
+from clickable.version import __container_minimum_required__
 
 
 class Container():
     def __init__(self, config, name=None, minimum_version=None):
         self.config = config
         self.docker_mode = self.config.needs_docker()
-        self.minimum_version = minimum_version
+        self.minimum_version = minimum_version \
+            if minimum_version \
+            else __container_minimum_required__
         self.docker_image = self.config.docker_image
         self.base_docker_image = self.docker_image
 
@@ -140,11 +143,17 @@ class Container():
                                  'Please run "clickable setup docker" first.')
 
     def is_systemd_used(self):
+        if sys.platform != "linux":
+            return False
+
         with open('/proc/1/comm', 'r', encoding='UTF-8') as f:
             init_system = f.read().strip()
             return init_system == "systemd"
 
     def docker_group_exists(self):
+        if sys.platform != "linux":
+            return False
+
         group_exists = False
         with open('/etc/group', 'r', encoding='UTF-8') as f:
             lines = f.readlines()
@@ -173,6 +182,9 @@ class Container():
 
         return 'docker' in groups
 
+    def is_docker(self):
+        return self.docker_executable == 'docker' and self.docker_mode
+
     def is_docker_ready(self):
         return self.is_docker_configured() and self.is_docker_service_running()
 
