@@ -1,8 +1,9 @@
-from os.path import expanduser, isfile
 from datetime import datetime, timedelta
+import os
 import json
 import re
 
+from clickable.config.constants import Constants
 from clickable.logger import logger
 
 REQUESTS_AVAILABLE = True
@@ -11,9 +12,9 @@ try:
 except ImportError:
     REQUESTS_AVAILABLE = False
 
-__version__ = '7.5.0'
+__version__ = '7.6.0'
 
-__container_minimum_required__ = 8
+__container_minimum_required__ = 9
 
 DATE_FORMAT = '%Y-%m-%dT%H:%M:%S'
 
@@ -42,12 +43,12 @@ def is_newer_than_running(version_numbers):
     return len(version_numbers) > len(running_version)
 
 
-def check_version(quiet=False):
+def check_version(quiet=False, force_download=False):
     if REQUESTS_AVAILABLE:
         version = None
         check = True
-        version_check = expanduser('~/.clickable/version_check.json')
-        if isfile(version_check):
+        version_check = os.path.join(Constants.clickable_dir, 'version_check.json')
+        if os.path.isfile(version_check) and not force_download:
             with open(version_check, 'r', encoding='UTF-8') as f:
                 try:
                     version_check_data = json.load(f)
